local function spawn_alert(parent)
  local alert_artifact = Alert.new()
  alert_artifact:sprite():set_never_flip(true)

  local movement_offset = parent:movement_offset()
  alert_artifact:set_offset(movement_offset.x, movement_offset.y - parent:height())

  parent:field():spawn(alert_artifact, parent:current_tile())
end


function status_init(status)
  local entity = status:owner()

  local original_color = entity:sprite():color()
  local oil_color = Color.new(32, 32, 32, 255)

  local color_component = entity:create_component(Lifetime.Scene)

  local sprite = entity:sprite()

  -- Handle color.
  color_component.on_init_func = function()
    sprite:set_color(oil_color)
    sprite:set_color_mode(ColorMode.Multiply)
  end

  color_component.on_update_func = function()
    sprite:set_color(oil_color)
    sprite:set_color_mode(ColorMode.Multiply)
  end

  -- Require a Fire attack that deals at least 1 damage.
  -- Increase the damage, spawn an alert, reset the color, and self-remove.
  local oil = AuxProp.new():require_hit_element(Element.Fire)
      :require_hit_damage(Compare.GT, 0)
      :increase_hit_damage("abs(DAMAGE + DAMAGE)"):with_callback(function()
        spawn_alert(entity)
        status:set_remaining_time(0)
      end)
      :once()

  entity:add_aux_prop(oil)

  status.on_delete_func = function()
    color_component:eject()
    sprite:set_color(original_color)
  end
end
